@@ -3,8 +3,6 @@ extern crate cc;
 
 use std::env;
 use std::path::PathBuf;
-use std::process::Command;
-use std::str;
 
 fn main() {
     // Tell cargo to invalidate the built crate whenever the wrapper changes
@@ -12,7 +10,7 @@ fn main() {
 
     // For Crane
     match env::var("LMOD_CMD") {
-        Ok(lmod_cmd) => {
+        Ok(_) => {
             let mut ld_path = env::var("LD_LIBRARY_PATH").expect("???");
             ld_path.push_str(":/util/comp/clang/13/lib");
             env::set_var("LD_LIBRARY_PATH", ld_path);
@@ -42,5 +40,4 @@ fn main() {
     cc::Build::new()
         .file("src/external/faddeeva/Faddeeva.c")
         .compile("faddeeva");
-
 }
