@@ -11,12 +11,13 @@ use ndarray::Dimension;
 use ndarray::{Ix1, Ix2};
 use rand::prelude::Distribution;
 use rand::Rng;
+use serde::{Deserialize, Serialize};
 
 /// Multivariate normal distribution with diagonal covariance
 pub type MultivariateTruncatedNormalDiag = MultivariateTruncatedNormal<Ix1>;
 
 /// Truncated multivariate normal distribution with full covariance
-#[derive(Clone, Debug)]
+#[derive(Clone, Debug, Serialize, Deserialize)]
 pub struct MultivariateTruncatedNormal<D: Dimension> {
     loc: Array1<f64>,
     scale: Array<f64, D>,
@@ -45,7 +46,7 @@ impl MultivariateTruncatedNormal<Ix2> {
         }
     }
 
-    pub fn try_get_tilting_solution(&self) -> Option<&TiltingSolution> {
+    pub const fn try_get_tilting_solution(&self) -> Option<&TiltingSolution> {
         self.tilting_solution.as_ref()
     }
 
@@ -69,7 +70,6 @@ impl MultivariateTruncatedNormal<Ix2> {
 
     pub fn cdf<R: Rng + ?Sized>(&mut self, n: usize, rng: &mut R) -> (f64, f64, f64) {
         let max_iters = self.max_iters;
-        assert!(self.tilting_solution.is_some());
         truncnorm::solved_mv_truncnormal_cdf(self.get_tilting_solution(None), n, max_iters, rng)
     }
 
